@@ -102,7 +102,10 @@ class VeoliaAPI:
             url,
             safe_params,
         )
-        headers = {}
+        headers = {
+            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.3",
+            "Accept": "*/*",
+        }
 
         if method == "GET":
             async with self.session.get(
